#[repr(u32)]pub enum PriceSource {
PRICE_SOURCE_EDIT_DLG = 0,
PRICE_SOURCE_FQ = 1,
PRICE_SOURCE_USER_PRICE = 2,
PRICE_SOURCE_XFER_DLG_VAL = 3,
PRICE_SOURCE_SPLIT_REG = 4,
PRICE_SOURCE_SPLIT_IMPORT = 5,
PRICE_SOURCE_STOCK_SPLIT = 6,
PRICE_SOURCE_STOCK_TRANSACTION = 7,
PRICE_SOURCE_INVOICE = 8,
PRICE_SOURCE_TEMP = 9,
PRICE_SOURCE_INVALID = 10,
}Expand description
Price source enum. Be sure to keep in sync with the source_name array in gnc-pricedb.c. These are in preference order, so for example a quote with PRICE_SOURCE_EDIT_DLG will overwrite one with PRICE_SOURCE_FQ but not the other way around.
Variants
PRICE_SOURCE_EDIT_DLG = 0
PRICE_SOURCE_FQ = 1
PRICE_SOURCE_USER_PRICE = 2
PRICE_SOURCE_XFER_DLG_VAL = 3
PRICE_SOURCE_SPLIT_REG = 4
PRICE_SOURCE_SPLIT_IMPORT = 5
PRICE_SOURCE_STOCK_SPLIT = 6
PRICE_SOURCE_STOCK_TRANSACTION = 7
PRICE_SOURCE_INVOICE = 8
PRICE_SOURCE_TEMP = 9
PRICE_SOURCE_INVALID = 10